@@ -98,8 +98,9 @@ def pirmyn():
         return
     if app.text.index('%s lineend' % position) == position:
         app.text.mark_set(INSERT, '%d.%d' % (line + 1, 0))
-    else:
-        app.text.mark_set(INSERT, '%d.%d +1c' % (line, offset))
+    else:     
+        adjust = 1 if app.text.get(INSERT) else 2
+        app.text.mark_set(INSERT, '%d.%d' % (line, offset + adjust))
     app.store_cursor()
 
 def atgal():
@@ -109,9 +110,10 @@ def atgal():
     if position == '1.0':
         return
     if app.text.index('%s linestart' % position) == position:
-        app.text.mark_set(INSERT, '%d.%d' % (line - 1, 0))
+        app.text.mark_set(INSERT, '%d lineend' % (line - 1))
     else:
-        app.text.mark_set(INSERT, '%d.%d -1c' % (line, offset))
+        adjust = 1 if app.text.get('insert -1c') else 2
+        app.text.mark_set(INSERT, '%d.%d' % (line, offset - adjust))
     app.store_cursor()
 
 def rašyti(ką):
